export declare const CREDIT_URL = "https://credit.niso.org/";
export type Options = {
    strict?: boolean;
};
/**
 * enum of the CRediT roles (https://credit.niso.org)
 */
export declare enum CreditRole {
    Conceptualization = "Conceptualization",
    DataCuration = "Data curation",
    FormalAnalysis = "Formal analysis",
    FundingAcquisition = "Funding acquisition",
    Investigation = "Investigation",
    Methodology = "Methodology",
    ProjectAdministration = "Project administration",
    Resources = "Resources",
    Software = "Software",
    Supervision = "Supervision",
    Validation = "Validation",
    Visualization = "Visualization",
    WritingOriginalDraft = "Writing \u2013 original draft",
    WritingReviewEditing = "Writing \u2013 review & editing"
}
/**
 * Descriptions of the CRediT roles (https://credit.niso.org)
 */
export declare const CreditDescriptions: Record<CreditRole, string>;
/**
 * CRediT roles as a list of strings
 */
export declare const ROLES: CreditRole[];
export declare function normalize(value?: CreditRole | string | null, opts?: Options): CreditRole | undefined;
/**
 * Validate that the input string is a valid CRediT role.
 *
 * @param value
 * @returns true if CRediT role is valid
 */
export declare function validate(value?: CreditRole | string | null, opts?: Options): boolean;
/**
 * Builds a canonical URL pointing to https://credit.niso.org/
 *
 * @param value
 * @returns the CRediT role as a string
 */
export declare function buildUrl(value?: CreditRole | string | null, opts?: Options): string | undefined;
export declare const credit: {
    validate: typeof validate;
    normalize: typeof normalize;
    buildUrl: typeof buildUrl;
};
